function [f, doy, P_x, P_y, P_xy, C_xy] = spectra_seasonal(varargin);

%
%  [f, doy, Pxx, Pyy, Pxy, Cxy] = spectra_seasonal(t, x, y)
%  
%  Seasonally stratified Cross spectral analysis between timeseries
%  x and y (must be of same length). The input time vector t must
%  be in MATLAB's datenum format. Only works for daily data.
%
%   The output quantities are as follows:
%  
%   f    - frequencies (divide by 2*pi to get cpd) ) [F x 1 row vector]
%   doy  - day of year vector (1, 2... 365) [365 x 1 row vector]
%   Pxx  - power spectrum of x [F x 365 matrix]
%   Pyy  - power spectrum of y  [F x 365 matrix]
%   Pxy  - cross-spectrum of x and y [F x 365 matrix]
%   Cxy  - coherence (not squared) between x and y [F x 365 matrix]
%  
%  If only x is specified then Pyy = Pxx and Pxy and Cxy are meaningless
%
%  Written by Eric Oliver, IMAS, University of Tasmania, 2015;
%  Adapted from original scripts written 2009-2012.
%

% grab inputs, nargs = 2 is x only, nargs = 3 is x and y
[cax,args,nargs] = axescheck(varargin{:});
t = args{1};
x = args{2};
if nargs == 3
    y = args{3};
else
    x = y;
end

% check the sample length
n = length(x);
if nargs == 3
  if ( n ~= length(y) )
    ['Data sets x and y of different lengths!']
    f = []; doy = []; P_x = []; P_y = []; P_xy = []; C_xy = [];
    return;
  end
end

% seasonal cycle of x and y spectra
  for tt = 1:(length(x)-180)
    [p0,f] = spec(x(tt:tt+180));
    var_x_var_tmp(tt) = var(x(tt:tt+180));
    P_x_tmp(tt,:) = p0;
    [p0,f] = spec(y(tt:tt+180));
    var_y_var_tmp(tt) = var(y(tt:tt+180));
    P_y_tmp(tt,:) = p0;
    [p0,f] = xspec(x(tt:tt+180),y(tt:tt+180));
    P_xy_tmp(tt,:) = p0;
  end
  T = t(91:(length(x)-90));
%
  nyears =  floor(length(T)/365);
  year0 = datevec(T(1)); season0 = T(1)-datenum([year0(1) 1 1])+1;
  x_var_tmp = reshape( var_x_var_tmp(1:nyears*365),365,nyears )';
  y_var_tmp = reshape( var_y_var_tmp(1:nyears*365),365,nyears )';
  for tt = 1:365
    w = ones(nyears,1); w(1) = (1/364)*(tt-1); w(end) = (1/364)*(-tt+365);
    var_x_var(tt) = wmean( x_var_tmp(:,tt) , w );
    var_y_var(tt) = wmean( y_var_tmp(:,tt) , w );
  end
  var_x_var = [ var_x_var((365-season0+1):end) var_x_var(1:(365-season0)) ];
  var_y_var = [ var_y_var((365-season0+1):end) var_y_var(1:(365-season0)) ];
  for fi=1:length(f)
    ps_tmp = reshape( P_x_tmp(1:nyears*365,fi) ,365,nyears)';
    for tt = 1:365
      w = ones(nyears,1); w(1) = (1/364)*(tt-1); w(end) = (1/364)*(-tt+365);
      P_x(tt,fi) = wmean( ps_tmp(:,tt) , w );
    end
    P_x(:,fi) = [ P_x((365-season0+1):end,fi) ; P_x(1:(365-season0),fi) ];
    ps_tmp = reshape( P_y_tmp(1:nyears*365,fi) ,365,nyears)';
    for tt = 1:365
      w = ones(nyears,1); w(1) = (1/364)*(tt-1); w(end) = (1/364)*(-tt+365);
      P_y(tt,fi) = wmean( ps_tmp(:,tt) , w );
    end
    P_y(:,fi) = [ P_y((365-season0+1):end,fi) ; P_y(1:(365-season0),fi) ];
    ps_tmp = reshape( P_xy_tmp(1:nyears*365,fi) ,365,nyears)';
    for tt = 1:365
      w = ones(nyears,1); w(1) = (1/364)*(tt-1); w(end) = (1/364)*(-tt+365);
      P_xy(tt,fi) = wmean( ps_tmp(:,tt) , w );
    end
    P_xy(:,fi) = [ P_xy((365-season0+1):end,fi) ; P_xy(1:(365-season0),fi) ];
  end
  %P_x_scale = P_x./repmat(var_x_var',1,length(f));
  %P_y_scale = P_y./repmat(var_y_var',1,length(f));
  %P_xy_scale = P_xy./sqrt(repmat(var_x_var',1,length(f)).*repmat(var_y_var',1,length(f)));
  C_xy = abs(P_xy)./sqrt(P_x.*P_y);
  doy = 1:365;

